aboutsummaryrefslogtreecommitdiff
path: root/src/video_core/rasterizer_interface.h
diff options
context:
space:
mode:
authorbunnei <bunneidev@gmail.com>2018-10-05 23:39:03 -0400
committerbunnei <bunneidev@gmail.com>2018-10-06 03:20:04 -0400
commit011cf77796aee57c23e97876aad65712efd6c92b (patch)
tree5cbed5aec5c9bb649bb068ddbf0d7189bd135085 /src/video_core/rasterizer_interface.h
parent749aef3dd0ccba7104ac630a59f01fa369c3581d (diff)
gl_rasterizer: Add rasterizer cache code to handle accerated fermi copies.
Diffstat (limited to 'src/video_core/rasterizer_interface.h')
-rw-r--r--src/video_core/rasterizer_interface.h11
1 files changed, 4 insertions, 7 deletions
diff --git a/src/video_core/rasterizer_interface.h b/src/video_core/rasterizer_interface.h
index cd819d69fe..06fc59dbe8 100644
--- a/src/video_core/rasterizer_interface.h
+++ b/src/video_core/rasterizer_interface.h
@@ -5,6 +5,7 @@
#pragma once
#include "common/common_types.h"
+#include "video_core/engines/fermi_2d.h"
#include "video_core/gpu.h"
#include "video_core/memory_manager.h"
@@ -33,13 +34,9 @@ public:
/// and invalidated
virtual void FlushAndInvalidateRegion(VAddr addr, u64 size) = 0;
- /// Attempt to use a faster method to perform a display transfer with is_texture_copy = 0
- virtual bool AccelerateDisplayTransfer(const void* config) {
- return false;
- }
-
- /// Attempt to use a faster method to perform a display transfer with is_texture_copy = 1
- virtual bool AccelerateTextureCopy(const void* config) {
+ /// Attempt to use a faster method to perform a surface copy
+ virtual bool AccelerateSurfaceCopy(const Tegra::Engines::Fermi2D::Regs::Surface& src,
+ const Tegra::Engines::Fermi2D::Regs::Surface& dst) {
return false;
}